/*
 * Copyright 2014-2020 Markus Prasser
 *
 * This file is part of Labcontrol.
 *
 *  Labcontrol is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Labcontrol is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Labcontrol.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SETTINGS_H
#define SETTINGS_H

#include <QDebug>
#include <QObject>

#include <string>
#include <boost/property_tree/ptree.hpp>
#include <boost/property_tree/json_parser.hpp>
#include <boost/foreach.hpp>

#include "client.h"

namespace pt = boost::property_tree;

namespace lc {

class Settings : public QObject {
    Q_OBJECT

public:
    Settings() = delete;
    explicit Settings( pt::ptree root );
    Settings( const Settings &argSettings ) = delete;
    Settings& operator=( const Settings &argSettings ) = delete;
    Settings( Settings &&argSettings ) = delete;
    Settings& operator=( Settings &&argSettings ) = delete;
    ~Settings();

    QVector< Client* > &GetClients() { return clients; }

    // get and set functions
    int GetChosenZTreePort() const { return chosenzTreePort; }
    void SetChosenZTreePort( const int argPort );
    QString GetLocalzLeafName() const { return localzLeafName; }
    void SetLocalzLeafName( const QString &argLocalzLeafName ) { localzLeafName = argLocalzLeafName; }
    QString GetLocalzLeafSize() const { return localzLeafSize; }
    void SetLocalzLeafSize( QString arg);

    // ptree childs
    const pt::ptree root;
    const pt::ptree binary_paths;
    const pt::ptree client;
    const pt::ptree server;
    const pt::ptree webcams_root;

    // constants
    const int defaultReceiptIndex = 0;
    const QString browserCmd;
    const QString clientBrowserCmd;
    const QString clientChromiumCmd;
    const QString dvipsCmd;
    const QString fileMngr;
    const QString killallCmd;
    const QString zleafExeName;
    const QString ztreeExeName;
    const QString latexCmd;
    const QString lcDataDir;
    const QString localUserName;
    const QString lprCmd;
    const QString netstatCmd;
    const QString netwBrdAddr;
    const QString orseeUrl;
    const QString pingCmd;
    const QString postscriptViewer;
    const QString ps2pdfCmd;
    const QString pkeyPathRoot;
    const QString pkeyPathUser;
    const QString rmCmd;
    const QString scpCmd;
    const QString serverIP;
    const QString sshCmd;
    const QString tasksetCmd;
    const QString termEmulCmd;
    const QString userNameOnClients;
    const QString vncViewer;
    const QString wakeonlanCmd;
    const QString webcamDisplayCmd;
    const QStringList webcams;
    const QStringList webcams_names;
    const QString wineCmd;
    const QString wmctrlCmd;
    const QString xsetCmd;
    const QString zTreeInstDir;
    const QString restartCrashedSessionScript;
    const QStringList adminUsers;
    const QStringList installedLaTeXHeaders;
    const QStringList installedZTreeVersions;
    const quint16 clientHelpNotificationServerPort = 0;
    const QString vncViewOnlyArguments;

private:
    static bool CheckPathAndComplain( const QString &argPath, const QString &argVariableName,
                                      const QString &argMessage );
    static QVector< Client* > CreateClients( const pt::ptree &clients,
                                             const QString &argPingCmd);
    static QMap< QString, Client* > CreateClIPsToClMap( const QVector< Client* > &argClients );
    QStringList DetectInstalledLaTeXHeaders() const;
    QStringList DetectInstalledzTreeVersions() const;
    static QStringList GetAdminUsers( const pt::ptree server );
    static quint16 GetClientHelpNotificationServerPort( const pt::ptree server );
    static QString GetLocalUserName();
    static QStringList GetWebcams(const pt::ptree server);
    static QStringList GetWebcamsNames(const pt::ptree server);

    int chosenzTreePort = 0;
    QVector< Client* > clients;
    QString localzLeafName;
    QString localzLeafSize;

public:
    const QMap< QString, Client* > clIPsToClMap;
};

}

#endif // SETTINGS_H
