/*
 * Copyright 2014-2020 Markus Prasser
 *
 * This file is part of Labcontrol.
 *
 *  Labcontrol is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Labcontrol is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Labcontrol.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <memory>

#include <QApplication>
#include <QDebug>

#include "Lib/settings.h"
#include "mainwindow.h"

std::unique_ptr<lc::Settings> settings;

int main(int argc, char *argv[]) {
  QApplication a{argc, argv};

  qRegisterMetaType<lc::Client::State>();
  qRegisterMetaType<lc::Client::State>("Client::State");
  qRegisterMetaType<lc::Client::State>("lc::Client::State");

  unsigned long i = 0;
    // hard coded, you can edit here, if you prefer a different location for your config file:
  std::vector<std::string> filenames = {"/usr/local/etc/labcontrol/labcontrol.json", "/etc/labcontrol/labcontrol.json", "./labcontrol.json", "/usr/local/etc/Labcontrol/Labcontrol.json", "/etc/Labcontrol/Labcontrol.json", "./Labcontrol.json"};
  for (i; i < filenames.size(); i++) { // if a configuration file was found, the loop breaks
    std::ifstream f(filenames[i].c_str());
    pt::ptree root;
    if (f.good()) {
        pt::read_json(f, root);

        settings.reset( new lc::Settings{root} );
        // clients?
        lc::MainWindow w;
        w.show();

        return a.exec();
        break;
    }
  }
  if (i == filenames.size()) QMessageBox::critical(NULL, QString("Error"), QString("No configuration file found."));
}
